import * as React from 'react';
import { createContext, useContext } from 'react';
var LocaleContext = /*#__PURE__*/createContext({
  locale: 'en-GB'
});
var LocaleContextProvider = function (_a) {
  var locale = _a.locale,
    children = _a.children;
  return /*#__PURE__*/React.createElement(LocaleContext.Provider, {
    value: {
      locale: locale
    }
  }, children);
};

/**
 * This hook uses the `LocaleContext` to return the locale data.
 * @example Use it with a default context
 * ```js
 * const { locale } = useLocale();
 * assertEqual(locale, 'en-GB');
 * ```
 * @example Use with a Provider
 * ```js
 * <LocaleContextProvider locale="nl-NL">
 *   ...
 *   const { locale } = useLocale();
 *   assertEqual(locale, 'nl-NL');
 *   ...
 * </LocaleContextProvider>
 * ```
 */
function useLocale() {
  return useContext(LocaleContext);
}
export { LocaleContextProvider, useLocale };
//# sourceMappingURL=index.js.map
