import { AvailableLocales } from './private/Locales';
/**
 * This hook uses the `LocaleContext` to return the locale data.
 * @example Use it with a default context
 * ```js
 * const { locale } = useLocale();
 * assertEqual(locale, 'en-GB');
 * ```
 * @example Use with a Provider
 * ```js
 * <LocaleContextProvider locale="nl-NL">
 *   ...
 *   const { locale } = useLocale();
 *   assertEqual(locale, 'nl-NL');
 *   ...
 * </LocaleContextProvider>
 * ```
 */
export declare function useLocale(): {
    locale: AvailableLocales;
};
export default useLocale;
